pub struct Point {
pub x: f32,
pub y: f32,
pub z: f32,
}Expand description
A Point is used to define the origin of the slats.
Fields
x: f32y: f32z: f32Implementations
Sourceimpl Point
impl Point
Sourcepub fn from_hef_part(part: String) -> Self
pub fn from_hef_part(part: String) -> Self
Parse a point from the part of a slat-line in a HEF, which contains the origin.
Sourcepub fn to_hef_part(&self) -> String
pub fn to_hef_part(&self) -> String
Format the point as used in HEF.